/*
 * The MIT License
 *
 * Copyright 2018-2020 Charles University
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package cz.cuni.mff.java.cv06;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;

public class PostfixCalc {

    public static void main(String[] args) {
        BufferedReader in = new BufferedReader(new InputStreamReader(System.in));
        String line;
        try {
            while ((line = in.readLine()) != null) {
                try {
                    int[] stack = new int[1024];  // limited stack only
                    int current = -1;
                    String[] elems = line.split(" ");  // we require empty spaces between entities in the line
                    for (String el : elems) {
                        switch (el) {
                            case "+" -> {
                                stack[current - 1] = stack[current - 1] + stack[current];
                                current--;
                            }
                            case "-" -> {
                                stack[current - 1] = stack[current - 1] - stack[current];
                                current--;
                            }
                            case "*" -> {
                                stack[current - 1] = stack[current - 1] * stack[current];
                                current--;
                            }
                            case "/" -> {
                                stack[current - 1] = stack[current - 1] / stack[current];
                                current--;
                            }
                            default -> stack[++current] = Integer.parseInt(el);
                        }
                    }
                    System.out.println(stack[current]);
                } catch (ArrayIndexOutOfBoundsException | NumberFormatException ex) {
                    System.out.println("Malformed expression");
                }
            }
        } catch (IOException ex) {
            System.out.println("IO exception");
        }
    }
}
